Structure Search

## 3.1 Structure Search

As an alternative to constructing a single structure, `NanoCap` includes a tool for finding low energy structures by performing a structure search. This is useful when finding the lowest energy topology is important or when an ensemble of structures is required.

The structure search options are accessed through the File–New Structure–Structure Search menu. The structure search window includes a panel of parameters that define the structure type and search criteria. Here the user can define the required structural properties as well as the force field and optimiser to use during the search. The search results are dynamically displayed in a table where the user can browse the details of each structure. During the search the user can view an individual structure by pressing the view button in the associated row in the table. This will load the structure into the main `NanoCap` window. An example of the structure search window during a search in shown in Fig. 5.

Figure 5: `NanoCap` structure search window during a search

After a structure search, the current set of results can be compared against the local and online (in future releases) databases. The columns in the structure search table denoted Local and Web indicate the presence of the structure in the associated databases. If a structure is not found it’s icon will change (to a + symbol) and it can be immediately added to the corresponding database with a single click. Results from a typical structure search after checking against the local `NanoCap` database are shown in Fig. 6.

Figure 6: `NanoCap` structure search window after a search and results have been checked against the local database